==> materialsml-0.2.2.tar.gz: materialsml-0.2.2/README.md <==
# materialsML

A Machine Learning package for materials informatics. A crafty data analysis complement to the materials database from [The Materials Project](https://materialsproject.org)


<center><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/materialsML.svg" width="400"></center>

## Getting Started 

<a href="https://colab.research.google.com/drive/19PD1d6FlRWKdhBYoTWkKfI9O3XiLDZeM?usp=sharing"><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/notebook.png"></a>


## Local Installation and Usage 

```ruby
pip install materialsml
```
It is recommended to run this package using a `virtualenv` virtual environment. To do so, follow the below simple protocol to create the virtual environment, run it, and install the package there:

```ruby 
virtualenv venv
source venv/bin/activate
pip install materialsml
python [your-script.py]
```
To exit the virtual environment, simply type `deactivate`. To access it at any other time, type `source venv/bin/activate` on the directory containing the `venv` folder. 


## viewer (in development)

<center><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/examples/images/materialsML_view0124.png" width="400"></center>


## Disclaimer: Use At Your Own Risk

This program is free software. It comes without any warranty, to the extent permitted by applicable law. You can redistribute it and/or modify it under the terms of the MIT LICENSE, as published by Andrew Garcia. See LICENSE below for more details.

[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://badges.mit-license.org)

**[MIT license](./LICENSE)** Copyright 2023 © <a href="https://github.com/andrewrgarcia" target="_blank">Andrew Garcia</a>.

==> materialsml-0.2.3.tar.gz: materialsml-0.2.3/README.md <==
# materialsML

A Machine Learning package for materials informatics. A crafty data analysis complement to the materials database from [The Materials Project](https://materialsproject.org)


<center><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/materialsML.svg" width="400"></center>

## Getting Started 

<a href="https://colab.research.google.com/drive/19PD1d6FlRWKdhBYoTWkKfI9O3XiLDZeM?usp=sharing"><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/notebook.png" width=600></a>


## Local Installation and Usage 

```ruby
pip install materialsml
```
It is recommended to run this package using a `virtualenv` virtual environment. To do so, follow the below simple protocol to create the virtual environment, run it, and install the package there:

```ruby 
virtualenv venv
source venv/bin/activate
pip install materialsml
python [your-script.py]
```
To exit the virtual environment, simply type `deactivate`. To access it at any other time, type `source venv/bin/activate` on the directory containing the `venv` folder. 


## viewer (in development)

<center><img src="https://raw.githubusercontent.com/andrewrgarcia/materialsML/main/examples/images/materialsML_view0124.png"></center>


## Disclaimer: Use At Your Own Risk

This program is free software. It comes without any warranty, to the extent permitted by applicable law. You can redistribute it and/or modify it under the terms of the MIT LICENSE, as published by Andrew Garcia. See LICENSE below for more details.

[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://badges.mit-license.org)

**[MIT license](./LICENSE)** Copyright 2023 © <a href="https://github.com/andrewrgarcia" target="_blank">Andrew Garcia</a>.
